Based on the mean and standard deviation of the elevation and rotation estimates this function will determine the region over which a given proportion of points would be expected to fall.
calculateEllipse(means, sd, alpha = 0.05)A numeric vector of length 2 giving the mean for the x direction and the mean for the y direction.
A numeric vector of length 2 giving the standard deviation for the x direction and the y direction.
A value between 0 and 1 that gives the confidence level.
A list of length 2 containing:
The x axis coordinates of the ellipse
The y axis coordinates of the ellipse
Based on the mean and standard deviation of the x and y direction the limits of an ellipse are determined.